#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ONE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ONE_HPP_INCLUDED

#include <boost/simd/constant/include/constants/one.hpp>

#endif
